==> dataone.test_utilities-3.3.0-py3-none-any.whl: d1_test/stress_tester/projects/combination_2/test_scripts/tier_1_mn_core_get_log_records.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2016 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
:mod:`tier_1_mn_core_get_log_records`
=====================================

:Created: 2011-04-22
:Author: DataONE (Dahl)
"""

import transaction


class Transaction(transaction.Transaction):
    def __init__(self):
        super().__init__()

    def d1_mn_api_call(self):
        """MNCore.getLogRecords() for specific object called by regular
        subject."""
        obj, subject = self.select_random_private_object()
        client = self.create_client_for_subject(subject)
        response = client.getLogRecordsResponse(pidFilter=obj)
        self.check_response(response)


if __name__ == '__main__':
    t = Transaction()
    t.run()
    # import cProfile
    # cProfile.run('t.run()', 'profile')

==> dataone.test_utilities-3.4.1-py3-none-any.whl: d1_test/stress_tester/projects/combination_2/test_scripts/tier_1_mn_core_get_log_records.py <==
#!/usr/bin/env python

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2019 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
:mod:`tier_1_mn_core_get_log_records`
=====================================

:Created: 2011-04-22
:Author: DataONE (Dahl)
"""

import transaction


class Transaction(transaction.Transaction):
    def __init__(self):
        super().__init__()

    def d1_mn_api_call(self):
        """MNCore.getLogRecords() for specific object called by regular subject."""
        obj, subject = self.select_random_private_object()
        client = self.create_client_for_subject(subject)
        response = client.getLogRecordsResponse(pidFilter=obj)
        self.check_response(response)


if __name__ == '__main__':
    t = Transaction()
    t.run()
    # import cProfile
    # cProfile.run('t.run()', 'profile')
